@@ -352,7 +352,11 @@ class IOingredientTool(object):
         toupdate = updatePositionsRadii(ingr)
         ingdic.update(toupdate)
         if numpy.sum(ingr.offset) != 0.0:
-            ingr.source["transform"]["offset"] = ingr.offset
+            if "transform" not in ingr.source:
+                ingr.source["transform"] = {"offset": ingr.offset}
+            else:
+                ingr.source["transform"]["offset"] = ingr.offset
+
         # reslt ?s
         if result:
             ingdic["results"] = []
@@ -487,14 +491,14 @@ def addCompartments(env, compdic, i, io_ingr):
             rep_file = ""
             if "rep_file" in comp_dic:
                 rep_file = str(comp_dic["rep_file"])
-            print(
-                "rep ?",
-                name,
-                geom,
-                rep,
-                rep_file,
-                (rep != "None" and len(rep) != 0 and rep != "" and rep == ""),
-            )
+            # print(
+            #    "rep ?",
+            #    name,
+            #    geom,
+            #    rep,
+            #    rep_file,
+            #    (rep != "None" and len(rep) != 0 and rep != "" and rep == ""),
+            # )
             #                print (len(rep),rep == '',rep=="",rep != "None",rep != "None" or len(rep) != 0)
             if rep != "None" and len(rep) != 0 and rep != "" and rep != "":
                 rname = rep_file.split("/")[-1]
@@ -1973,6 +1977,8 @@ def setupFromJsonDic(
             if k in options:
                 setattr(env, k, options[k])
         env.boundingBox = options["boundingBox"]
+        if None in env.boundingBox[0] or None in env.boundingBox[1]:
+            env.boundingBox = ([0, 0, 0], [1000, 1000, 1000])
     if "gradients" in env.jsondic:
         env.gradients = {}
         gradientsnode = env.jsondic["gradients"]
@@ -2039,15 +2045,15 @@ def setupFromJsonDic(
                 rep_file = ""
                 if "rep_file" in comp_dic:
                     rep_file = str(comp_dic["rep_file"])
-                print(
-                    "rep ?",
-                    name,
-                    geom,
-                    gname,
-                    rep,
-                    rep_file,
-                    (rep != "None" and len(rep) != 0 and rep != "" and rep == ""),
-                )
+                # print(
+                #     "rep ?",
+                #     name,
+                #     geom,
+                #     gname,
+                #     rep,
+                #     rep_file,
+                #     (rep != "None" and len(rep) != 0 and rep != "" and rep == ""),
+                # )
                 #                print (len(rep),rep == '',rep=="",rep != "None",rep != "None" or len(rep) != 0)
                 if rep != "None" and len(rep) != 0 and rep != "" and rep != "":
                     rname = rep_file.split("/")[-1]
